@@ -27,12 +27,13 @@ from threading import Thread
 import colemen_string_utils as strUtils
 import logging
 import ftputil
+import utils.resources
 
 logger = logging.getLogger(__name__)
 
 # pylint: disable=line-too-long
-DEST_PATH_SYNONYMS = ["dest", "dst", "dest path", "destination", "destination path", "dst path", "target", "target path"]
-SRC_PATH_SYNONYMS = ["source", "src", "src path", "source path", "file path"]
+# DEST_PATH_SYNONYMS = utils.resources.DEST_PATH_SYNONYMS
+# SRC_PATH_SYNONYMS = utils.resources.SRC_PATH_SYNONYMS
 
 # todo - DOCUMENTATION FOR METHODS
 
@@ -291,12 +292,12 @@ def _parse_copy_data_from_obj(file_obj):
         else:
             print(f"Invalid list/tuple provided for copy file. Must be [source_file_path, destination_file_path]")
     if isinstance(file_obj, (dict)):
-        for syn in SRC_PATH_SYNONYMS:
+        for syn in utils.resources.SRC_PATH_SYNONYMS:
             synvar = obj._gen_variations(syn)
             for sv in synvar:
                 if sv in file_obj:
                     data['src_path'] = file_obj[sv]
-        for syn in DEST_PATH_SYNONYMS:
+        for syn in utils.resources.DEST_PATH_SYNONYMS:
             synvar = obj._gen_variations(syn)
             for sv in synvar:
                 if sv in file_obj:
@@ -444,7 +445,6 @@ def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
         try:
             if ftp is not None:
                 dirUtils.create(os.path.dirname(file['dst_path']), False, ftp)
-                # ftp.makedirs(os.path.dirname(file['dst_path']))
                 ftp.upload_if_newer(file['src_path'], file['dst_path'])
                 continue
 
